package com.pj.tb_goods;

import java.io.IOException;
import java.util.List;

import com.pj.api.dto.GoodsDto;
import com.pj.api.dto.HtGoodsDto;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.multipart.MultipartFile;


/**
 *商品管理
 * @author qzy
 */
@RestController
@RequestMapping("/TbGoods/")
public class TbGoodsController {

	/** 底层 Service 对象 */
	@Autowired
	TbGoodsService tbGoodsService;

	/** 增添加商品 */
	@RequestMapping("add")
	@SaCheckPermission(TbGoods.PERMISSION_CODE_ADD)
	public AjaxJson add(TbGoods t){
		tbGoodsService.add(t);
		t = tbGoodsService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */
	@RequestMapping("delete")
	@SaCheckPermission(TbGoods.PERMISSION_CODE_DEL)
	public AjaxJson delete(Long id){
		 tbGoodsService.delete(id);
		return AjaxJson.getSuccess();
	}

	/** 删 - 根据id列表 */
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbGoods.PERMISSION_CODE_DEL)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
		int line = SP.publicMapper.deleteByIds(TbGoods.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}

	/** 改 */
	@RequestMapping("update")
	@SaCheckPermission(TbGoods.PERMISSION_CODE_EDIT)
	public AjaxJson update(TbGoods t){
		tbGoodsService.update(t);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */
	@RequestMapping("getById")
		@SaCheckPermission(TbGoods.PERMISSION_CODE)
	public AjaxJson getById(String id){
		TbGoods t = tbGoodsService.getById(id);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */
	@RequestMapping("getList")
		@SaCheckPermission(TbGoods.PERMISSION_CODE)
	public AjaxJson getList() {
		SoMap so = SoMap.getRequestSoMap();
		List<TbGoods> list = tbGoodsService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}



	/** 改 - 状态(0=禁用,1=启用) */
	@RequestMapping("updateStatus")
	@SaCheckPermission(TbGoods.PERMISSION_CODE_EDIT)
	public AjaxJson updateStatus(String id, String value){
		int line = SP.publicMapper.updateColumnById(TbGoods.TABLE_NAME, "status", value, id);
		return AjaxJson.getByLine(line);
	}
	/**
	 * 数据导入接口
	 * @param file
	 * @return
	 */
	@RequestMapping("goodsImport")
	@ResponseBody
	public AjaxJson dataImport(@RequestParam("file") MultipartFile file){
		try {
			String importData = tbGoodsService.importData(file);
			AjaxJson.getSuccess(importData);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		return AjaxJson.getError();
	}

	/**
	 * 导出
	 * @param keyword
	 * @return
	 */
	@RequestMapping("goodsOutport")
	@ResponseBody
	public AjaxJson dataOutport(@RequestParam(value = "keyword",required = false) String keyword,@RequestParam(value = "filepath",required = false)String filepath){
		try {
			String importData = tbGoodsService.outportExcel(keyword,filepath);
			AjaxJson.getSuccess(importData);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		return AjaxJson.getError();
	}


/* ---           正常业务方法 👆👆  rpc远程调用👇👇                              ---*/
	/** 查 - 根据id */
	@RequestMapping("rpc/getByGoodsId")
	public GoodsDto getByGoodsId(@RequestParam("goodsId") Long goodsId){
		GoodsDto t = tbGoodsService.selectById(goodsId);
		return t;
	}

	/** 远程调用: 同步航通海关监管商品信息 */
	@RequestMapping("rpc/goodsDto")
	public boolean goodsDto(@RequestBody HtGoodsDto htGoodsDto){
		boolean b = tbGoodsService.goodsDto(htGoodsDto);
		return b;
	}


}
