package com.pj.tb_import_order;

import java.util.List;

import com.pj.api.dto.HtImportOrderDto;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_import_order -- 进口申报单
 * @author lbl
 */
@RestController
@RequestMapping("/TbImportOrder/")
public class TbImportOrderController {

	/** 底层 Service 对象 */
	@Autowired
	TbImportOrderService tbImportOrderService;

	/** 增 */
	@RequestMapping("add")
	@SaCheckPermission(TbImportOrder.PERMISSION_CODE_ADD)
	public AjaxJson add(TbImportOrder t){
		tbImportOrderService.add(t);
		t = tbImportOrderService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */
	@RequestMapping("delete")
	@SaCheckPermission(TbImportOrder.PERMISSION_CODE_DEL)
	public AjaxJson delete(Long id){
		 tbImportOrderService.delete(id);
		return AjaxJson.getSuccess();
	}

	/** 删 - 根据id列表 */
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbImportOrder.PERMISSION_CODE_DEL)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
		int line = SP.publicMapper.deleteByIds(TbImportOrder.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}

	/** 改 */
	@RequestMapping("update")
	@SaCheckPermission(TbImportOrder.PERMISSION_CODE_EDIT)
	public AjaxJson update(TbImportOrder t){
		tbImportOrderService.update(t);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */
	@RequestMapping("getById")
		@SaCheckPermission(TbImportOrder.PERMISSION_CODE)
	public AjaxJson getById(Long id){
		TbImportOrder t = tbImportOrderService.getById(id);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */
	@RequestMapping("getList")
		@SaCheckPermission(TbImportOrder.PERMISSION_CODE)
	public AjaxJson getList() {
		SoMap so = SoMap.getRequestSoMap();
		List<TbImportOrder> list = tbImportOrderService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}

	@PostMapping("audit")
	@SaCheckPermission(TbImportOrder.PERMISSION_CODE_ADD)
	public AjaxJson audit(Long id, Integer judgeStatus, @RequestParam(value = "judgeContent",required = false)String judgeContent) {
		return AjaxJson.toAjax(tbImportOrderService.audit(id, judgeStatus, judgeContent));
	}



	/*-----           正常业务逻辑👆👆    rpc远程调用👇👇 -----*/

	/** 远程调用 进口申报单同步 */
	@PostMapping("rpc/importOrderDto")
	public boolean importOrderDto(@RequestBody HtImportOrderDto importOrderDto) {
		boolean result = tbImportOrderService.importOrderDto(importOrderDto);
		return result;
	}






}
