package com.pj.tb_people_tax_account;

import java.util.List;
import com.pj.api.dto.PeopleTaxAccountDto;
import com.pj.utils.so.SoMap;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_people_tax_account -- 边民-税务开户信息
 * @author lbl
 */
@RestController
@RequestMapping("/TbPeopleTaxAccount/")
public class TbPeopleTaxAccountController {

	/** 底层 Service 对象 */
	@Autowired
	private TbPeopleTaxAccountService tbPeopleTaxAccountService;

	/** 增 */
	@RequestMapping("add")
	@SaCheckPermission(TbPeopleTaxAccount.PERMISSION_CODE_ADD)
	public AjaxJson add(TbPeopleTaxAccount t){

		tbPeopleTaxAccountService.add(t);
		t = tbPeopleTaxAccountService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */
	@RequestMapping("delete")
	@SaCheckPermission(TbPeopleTaxAccount.PERMISSION_CODE_DEL)
	public AjaxJson delete(Long id){
		 tbPeopleTaxAccountService.delete(id);
		return AjaxJson.getSuccess();
	}

	/** 删 - 根据id列表 */
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbPeopleTaxAccount.PERMISSION_CODE_DEL)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
		int line = SP.publicMapper.deleteByIds(TbPeopleTaxAccount.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}

	/** 改 */
	@RequestMapping("update")
	@SaCheckPermission(TbPeopleTaxAccount.PERMISSION_CODE_EDIT)
	public AjaxJson update(TbPeopleTaxAccount t){
		tbPeopleTaxAccountService.update(t);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */
	@RequestMapping("getById")
		@SaCheckPermission(TbPeopleTaxAccount.PERMISSION_CODE)
	public AjaxJson getById(String id){
		TbPeopleTaxAccount t = tbPeopleTaxAccountService.getById(id);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */
	@RequestMapping("getList")
		@SaCheckPermission(TbPeopleTaxAccount.PERMISSION_CODE)
	public AjaxJson getList() {
		SoMap so = SoMap.getRequestSoMap();
		List<TbPeopleTaxAccount> list = tbPeopleTaxAccountService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}


	/**
	 * 根据ID获取边民信息
	 */
	@PostMapping("rpc/getTaxAccountByPeopleId")
	public PeopleTaxAccountDto getTaxAccountByPeopleId(@RequestParam("peopleId") Long peopleId) {
		PeopleTaxAccountDto dto = new PeopleTaxAccountDto();
		SoMap so = new SoMap();
		so.put("peopleId",peopleId);
		List<TbPeopleTaxAccount> list = tbPeopleTaxAccountService.getList(so);
		if(list.size()>0) BeanUtils.copyProperties(list.get(0), dto);
		return dto;
	}

}
