package com.pj.project.tb_agreement;

import java.util.List;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_agreement -- 隐私政策管理
 * @author qzy 
 */
@RestController
@RequestMapping("/TbAgreement/")
public class TbAgreementController {

	/** 底层 Service 对象 */
	@Autowired
	TbAgreementService tbAgreementService;

	/** 增 */  
	@RequestMapping("add")
	@SaCheckPermission(TbAgreement.PERMISSION_CODE_ADD)
	public AjaxJson add(TbAgreement t){
		tbAgreementService.add(t);
		t = tbAgreementService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */  
	@RequestMapping("delete")
	@SaCheckPermission(TbAgreement.PERMISSION_CODE_DEL)
	public AjaxJson delete(Long id){
		 tbAgreementService.delete(id);
		return AjaxJson.getSuccess();
	}
	
	/** 删 - 根据id列表 */  
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbAgreement.PERMISSION_CODE_DEL)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class); 
		int line = SP.publicMapper.deleteByIds(TbAgreement.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}
	
	/** 改 */  
	@RequestMapping("update")
	@SaCheckPermission(TbAgreement.PERMISSION_CODE_EDIT)
	public AjaxJson update(TbAgreement t){
		tbAgreementService.update(t);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */  
	@RequestMapping("getById")
		@SaCheckPermission(TbAgreement.PERMISSION_CODE)
	public AjaxJson getById(Integer id){
		TbAgreement t = tbAgreementService.getById(id);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */  
	@RequestMapping("getList")
		@SaCheckPermission(TbAgreement.PERMISSION_CODE)
	public AjaxJson getList() { 
		SoMap so = SoMap.getRequestSoMap();
		List<TbAgreement> list = tbAgreementService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}


	/**
	 * 根据类型获取其版本号最大的那一条数据
	 * @param textType 类型[1=隐私政策管理,2=服务协议]
	 * @return
	 */
	@RequestMapping("getMaxVersion")
	@SaCheckPermission(TbAgreement.PERMISSION_CODE)
	public AjaxJson getMaxVersion(Integer textType){
		TbAgreement t = tbAgreementService.getMaxVersion(textType);
		return AjaxJson.getSuccessData(t);
	}







}
