package com.pj.project.tb_driver;

import java.io.IOException;
import java.util.List;

import com.pj.api.dto.DriverDto;
import com.pj.enummj.DeleteStatus;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.multipart.MultipartFile;


/**
 * Controller: tb_driver -- 司机
 * @author qzy 
 */
@RestController
@RequestMapping("/TbDriver/")
public class TbDriverController {

	/** 底层 Service 对象 */
	@Autowired
	TbDriverService tbDriverService;

	/** 增 */  
	@RequestMapping("add")
	@SaCheckPermission(TbDriver.PERMISSION_CODE_ADD)
	public AjaxJson add(TbDriver t){
		tbDriverService.add(t);
		t = tbDriverService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */  
	@RequestMapping("delete")
	@SaCheckPermission(TbDriver.PERMISSION_CODE_DEL)
	public AjaxJson delete(Long id){
		 tbDriverService.delete(id);
		return AjaxJson.getSuccess();
	}
	
	/** 删 - 根据id列表 */  
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbDriver.PERMISSION_CODE_DEL)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class); 
		int line = SP.publicMapper.deleteByIds(TbDriver.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}
	
	/** 改 */  
	@RequestMapping("update")
	@SaCheckPermission(TbDriver.PERMISSION_CODE_EDIT)
	public AjaxJson update(TbDriver t){
		tbDriverService.update(t);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */  
	@RequestMapping("getById")
		@SaCheckPermission(TbDriver.PERMISSION_CODE)
	public AjaxJson getById(Long id){
		TbDriver t = tbDriverService.getById(id);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */  
	@RequestMapping("getList")
		@SaCheckPermission(TbDriver.PERMISSION_CODE)
	public AjaxJson getList() { 
		SoMap so = SoMap.getRequestSoMap();
		so.put("deleteStatus", DeleteStatus.DELETE_STATUS_ON.getCode());
		List<TbDriver> list = tbDriverService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}





	/**
	 * 数据导入接口
	 * @param file
	 * @return
	 */
	@RequestMapping("driverImport")
	@ResponseBody
	public AjaxJson dataImport(@RequestParam("file") MultipartFile file){
		try {
			String importData = tbDriverService.importData(file);
			AjaxJson.getSuccess(importData);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		return AjaxJson.getError();
	}

	/**
	 * 导出
	 * @param keyword
	 * @return
	 */
	@RequestMapping("driverOutport")
	@ResponseBody
	public AjaxJson dataOutport(@RequestParam(value = "keyword",required = false) String keyword,@RequestParam(value = "filepath",required = false)String filepath){
		try {
			String importData = tbDriverService.outportExcel(keyword,filepath);
			AjaxJson.getSuccess(importData);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		return AjaxJson.getError();
	}


	/*------            正常业务👆👆    rpc远程调用👇👇                         -----------*/

	/** 用户在APP注册时选择身份则创建一个对应身份的实体 */
	@RequestMapping("driverDto")
	public boolean driverDto(@RequestBody DriverDto driverDto){
		boolean b = tbDriverService.driverDto(driverDto);
		return b;
	}


}
